{ pkgs, lib, ... }:
with lib;
with lib.metacfg;
{
  imports = [ ./hardware-configuration.nix ];

  metacfg = {
    base.enable = true;
    gui.enable = true;
    nix-ld.enable = true;
    nix.enable = true;
    podman.enable = true;
    secureboot.enable = true;
    user.extraGroups = [ "docker" ];
  };

  environment.systemPackages = with pkgs; [
    azure-cli
    cloudflare-warp
    desktop-file-utils
    kubectl
    kubectx
    k9s
    attic-client
  ];
  services.printing.drivers = with pkgs; [
    metacfg.dcpl2530dw-cups
    gutenprintBin
    gutenprint
  ];

  services.resolved.enable = true;
  services.resolved.dnssec = "allow-downgrade";

  hardware.printers.ensurePrinters = [
    {
      name = "Brother_DCP-L2530DW_series";
      location = "Dach";
      deviceUri = "dnssd://Brother%20DCP-L2530DW%20series._ipp._tcp.local/?uuid=e3248000-80ce-11db-8000-cc6b1e5cd0ea";
      model = "brother-DCPL2530DW-cups-en.ppd";
      ppdOptions = {
        PageSize = "A4";
      };
    }
    {
      name = "Canon_MG6300_series";
      location = "Dach";
      deviceUri = "dnssd://Canon%20MG6300%20series._ipp._tcp.local/?uuid=00000000-0000-1000-8000-2C9EFC9C7BA5";
      model = "gutenprint.5.3://bjc-PIXMA-MG6350/expert";
      ppdOptions = {
        PageSize = "A4";
      };
    }
  ];

  systemd.packages = [ pkgs.cloudflare-warp ]; # for warp-cli

  virtualisation = {
    docker.enable = true;
    libvirtd.enable = true;
    podman.dockerCompat = false;
  };

  system.autoUpgrade = {
    enable = true;
    operation = "boot";
    allowReboot = false;
  };

  services.trezord.enable = true;

  system.stateVersion = "23.11";
}
